;;; Plugin  : Crayon Text - for Gimp-2.6.12
;;; Author  : Rod Detmer
;;; Date    : August 24th 2012
;;; Revision: 1.0
;;; 					
;;; Latest version at: http://www.gimpchat.com
;;; Required : Gimp 2.6
;;;
;;; Description: 
;;; Applies a crayolal text effect to your text layer
;;; -----------------------------------------------------------------------------
;;; Change Log:
;;; Version-1.0
;;;
;;; License:
;;; This program is free software; you can redistribute it and/or modify
;;; it under the terms of the GNU General Public License as published by
;;; the Free Software Foundation; either version 2 of the License, or
;;; (at your option) any later version.
;;; 
;;; This program is distributed in the hope that it will be useful,
;;; but WITHOUT ANY WARRANTY; without even the implied warranty of
;;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
;;; GNU General Public License for more details.
;;; 
;;; You should have received a copy of the GNU General Public License
;;; along with this program; if not, write to the Free Software
;;; Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.


(define (script-fu-crayon-text image layer mycolor Myiterations)
  
  ;; lets set the undo up here
  (gimp-image-undo-group-start image)
  ;; start the crayon effect and displace the pixels a bit
  (plug-in-spread RUN-NONINTERACTIVE image layer 2 2)
  (plug-in-displace RUN-NONINTERACTIVE image layer  5 4 0 0 layer layer 1)
  
  ;; grab the color for the crayon  
  (gimp-context-set-foreground mycolor)
  ;; needs a bit more texturing before fill 
  (plug-in-engrave RUN-NONINTERACTIVE image layer 3 1)
  
  ;; fill the text with the color
  (gimp-selection-layer-alpha layer)
  ;(gimp-image-select-item image 0 layer) deprecated in Gimp-2.8
  (gimp-edit-bucket-fill layer 0 0 100 255 1 1 1)
  
  ;; add some noise to the text
  (plug-in-hsv-noise RUN-NONINTERACTIVE image layer 1 0 20 25)
  (gimp-selection-none image)
  
  ;; we need to select just the user chosen colors here
  (gimp-by-color-select layer mycolor 255 1 0 1 0 1)
  ;(gimp-image-select-color image 0 layer mycolor) deprecated in Gimp-2.8
  (plug-in-colortoalpha RUN-NONINTERACTIVE image layer mycolor)
  
  ;; we need some more displacement here
  (plug-in-displace RUN-NONINTERACTIVE image layer  7 7 0 0 layer layer 1)
  ;;
  ;;test wind, and whirl and pinch settings
  (gimp-selection-layer-alpha layer)  
  (plug-in-wind RUN-NONINTERACTIVE image layer 10 0 10 1 1)
  ;(plug-in-whirl-pinch RUN-NONINTERACTIVE image layer 90 0 1)
  (gimp-by-color-select layer mycolor 255 1 0 1 0 1)
  ;(gimp-edit-bucket-fill layer 0 0 100 255 1 1 1)  
  ;;
  ;;
  ;;This displaces the pixels inside the text to look more like crayon
  (plug-in-spread RUN-NONINTERACTIVE image layer 1 1)
  (plug-in-displace RUN-NONINTERACTIVE image layer  5 4 0 0 layer layer 1)
  ;; grab the users chosen color
  (gimp-context-set-foreground mycolor)
  ;; add some graininess to the texture
  ;;(plug-in-engrave RUN-NONINTERACTIVE image layer 3 1)

  
  ;; fill the layer with users chosen color
  (gimp-selection-layer-alpha layer)  
  (gimp-edit-bucket-fill layer 0 0 100 255 1 1 1)
  (plug-in-hsv-noise RUN-NONINTERACTIVE image layer 1 0 20 25)
  (gimp-selection-none image)
  (gimp-by-color-select layer mycolor 255 1 0 1 0 1)
  (plug-in-colortoalpha RUN-NONINTERACTIVE image layer mycolor)
  ;;
  ;;
  (gimp-selection-none image) 
  
  ;; we lost some texture so lets replace it a little bit  
  (gimp-brightness-contrast layer 27 27)
  
  ;;
  ;;Test warp feature to allow iterations of messyness
  (gimp-layer-resize-to-image-size layer) 
  ;; Messiness adjustments  
  (plug-in-warp RUN-NONINTERACTIVE image layer 5 layer Myiterations 0 90 0 layer 0 1 0 0 0 0 0)
  ;; lets try and fill in the empty spaces in the text a bit
  (gimp-selection-layer-alpha layer)
  (gimp-context-set-foreground mycolor)
  (gimp-edit-bucket-fill layer 0 0 100 255 1 1 1)
  ;; test for darker color  
  (gimp-layer-copy layer 3)

  ;; set everything back to normal and display new image
  (gimp-selection-none image)  
  (gimp-brightness-contrast layer 9 23)
  (gimp-context-set-foreground '(0 0 0))
  (gimp-context-set-background '(255 255 255))   
  (gimp-displays-flush image)
  (gimp-image-undo-group-end image)  
)

(script-fu-register
 "script-fu-crayon-text"
 "<Image>/Script-Fu/Text Effects/Crayon Text"
 "Applies a crayolal text effect to your text layer"
 "Rod Detmer"
 "Rod Detmer"
 "August 2012" 
 "RGB* GRAY* INDEXED*"
 SF-IMAGE "The Image" 0
 SF-DRAWABLE "The Layer" 0
 SF-COLOR "Crayon Color (fg)" '(20 130 235)
 SF-ADJUSTMENT "Messyness" '(3 1 5 1 10 0 SF-SLIDER) 
)
